@@ -14,15 +14,14 @@
  * Boston, MA 021110-1307, USA.
  */
 
+#include "kerncompat.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <limits.h>
 #include <getopt.h>
-
-#include "cmds/commands.h"
-#include "common/utils.h"
 #include "common/help.h"
+#include "common/string-utils.h"
+#include "cmds/commands.h"
 
 #define USAGE_SHORT		1U
 #define USAGE_LONG		2U
@@ -209,15 +208,13 @@ static int do_usage_one_command(const char * const *usagestr,
 	fputc('\n', outf);
 
 	while (*usagestr) {
-		if (strcmp(*usagestr, HELPINFO_INSERT_GLOBALS) == 0) {
+		if (strcmp(*usagestr, HELPINFO_INSERT_FORMAT) == 0) {
 			int i;
 
-			fputc('\n', outf);
 			/*
 			 * We always support text, that's on by default for all
 			 * commands
 			 */
-			fprintf(outf, "%*sGlobal options:\n", pad, "");
 			fprintf(outf, "%*s--format TYPE      where TYPE is: %s",
 					pad, "", output_formats[0].name);
 			for (i = 1; i < ARRAY_SIZE(output_formats); i++) {
